@@ -12,8 +12,8 @@ Abstract representation of Atoms (:mod:`sknano.chemistry._atoms`)
    attributes.
 
 """
-from __future__ import division, absolute_import, print_function
-__docformat__ = 'restructuredtext'
+from __future__ import absolute_import, division, print_function
+__docformat__ = 'restructuredtext en'
 
 import copy
 import math
@@ -30,8 +30,7 @@ except ImportError:
           'nearest-neighbor queries between `Atoms`.')
     has_kdtree = False
 
-from ..tools import check_type, xyz_axes
-from ._atom import Atom
+from ..tools import xyz_axes
 
 __all__ = ['Atoms']
 
@@ -63,7 +62,6 @@ class Atoms(MutableSequence):
         self._molecule_ids = []
         self._charges = []
         self._coords = []
-        self._positions = []
         self._masses = []
         self._velocities = []
         self._forces = []
@@ -88,54 +86,35 @@ class Atoms(MutableSequence):
         self._NN_cutoff = np.inf
 
         if atoms is not None:
-            if isinstance(atoms, Atoms):
+            try:
                 if copylist and not deepcopy:
                     self._atoms.extend(atoms.atoms[:])
                 elif deepcopy:
                     self._atoms.extend(copy.deepcopy(atoms.atoms))
                 else:
                     self._atoms.extend(atoms.atoms)
-            elif isinstance(atoms, list):
-                if copylist and not deepcopy:
-                    self._atoms = atoms[:]
-                elif deepcopy:
-                    self._atoms = copy.deepcopy(atoms)
-                else:
-                    self._atoms = atoms
+            except AttributeError:
+                if isinstance(atoms, list):
+                    if copylist and not deepcopy:
+                        self._atoms = atoms[:]
+                    elif deepcopy:
+                        self._atoms = copy.deepcopy(atoms)
+                    else:
+                        self._atoms = atoms
 
-                for atom in self._atoms:
-                    self._check_type(atom)
-                    for p, plist in self._property_lists.iteritems():
-                        plist.append(getattr(atom, p))
-            else:
-                raise TypeError('`Atoms(atoms={!r})` '.format(atoms) +
-                                'is not a valid `Atoms` constructor '
-                                'argument.\n atoms must be `None`, a list '
-                                'of `Atom` objects, or an `Atoms` object '
-                                'instance.')
+                    for atom in self._atoms:
+                        for p, plist in self._property_lists.iteritems():
+                            plist.append(getattr(atom, p))
+                else:
+                    raise TypeError('`Atoms(atoms={!r})` '.format(atoms) +
+                                    'is not a valid `Atoms` constructor '
+                                    'argument.\n atoms must be `None`, a list '
+                                    'of `Atom` objects, or an `Atoms` object '
+                                    'instance.')
 
             if use_kdtree:
                 self._atom_tree = self.atom_tree
 
-    def _check_type(self, value):
-        """Check that value is instance of `Atom` class.
-
-        Parameters
-        ----------
-        value : `Atom`
-            value to type check
-
-        Raises
-        ------
-        `TypeError`
-            if `value` is not instance of `Atom`
-
-        """
-        try:
-            check_type(value, allowed_types=(Atom,))
-        except TypeError:
-            raise TypeError('{} is not an Atom.'.format(value))
-
     def __str__(self):
         """Return string representation of `Atoms`."""
         atoms_str = ''
@@ -184,16 +163,6 @@ class Atoms(MutableSequence):
             self._atom_tree = KDTree(self.coords)
         return self._atom_tree
 
-    @property
-    def charges(self):
-        """Return list of `Atom` charges."""
-        #self._charges_array = np.asarray(self._charges)
-        charges = []
-        for atom in self._atoms:
-            charges.append(atom.q)
-        self._charges = charges[:]
-        return np.asarray(self._charges)
-
     @property
     def CM(self):
         """Center-of-Mass coordinates of `Atoms`.
@@ -209,6 +178,47 @@ class Atoms(MutableSequence):
         MxR = masses.T * coords
         return np.sum(MxR, axis=0) / np.sum(masses)
 
+    @property
+    def M(self):
+        """Total mass of `Atoms`."""
+        return math.fsum(self.masses)
+
+    @property
+    def Natoms(self):
+        """Number of atoms in `Atoms`."""
+        return len(self._atoms)
+
+    @property
+    def NN_cutoff(self):
+        return self._NN_cutoff
+
+    @NN_cutoff.setter
+    def NN_cutoff(self, value):
+        self._NN_cutoff = value
+
+    @property
+    def NN_number(self):
+        return self._NN_number
+
+    @NN_number.setter
+    def NN_number(self, value):
+        self._NN_number = int(value)
+
+    @property
+    def Ntypes(self):
+        """Number of atom types in `Atoms`."""
+        return len(self.atomtypes.keys())
+
+    @property
+    def charges(self):
+        """Return list of `Atom` charges."""
+        #self._charges_array = np.asarray(self._charges)
+        charges = []
+        for atom in self._atoms:
+            charges.append(atom.q)
+        self._charges = charges[:]
+        return np.asarray(self._charges)
+
     @property
     def coords(self):
         """Return array of `Atom` coordinates."""
@@ -218,15 +228,6 @@ class Atoms(MutableSequence):
         self._coords = coords[:]
         return np.asarray(self._coords)
 
-    @property
-    def positions(self):
-        """Return array of `Atom` positions."""
-        positions = []
-        for atom in self._atoms:
-            positions.append(atom.r)
-        self._positions = positions[:]
-        return np.asarray(self._positions)
-
     @property
     def coordination_numbers(self):
         """Return array of `Atom` coordination numbers."""
@@ -377,21 +378,6 @@ class Atoms(MutableSequence):
         """
         return self.M
 
-    @property
-    def M(self):
-        """Total mass of `Atoms`."""
-        return math.fsum(self.masses)
-
-    @property
-    def Natoms(self):
-        """Number of atoms in `Atoms`."""
-        return len(self._atoms)
-
-    @property
-    def Ntypes(self):
-        """Number of atom types in `Atoms`."""
-        return len(self.atomtypes.keys())
-
     @property
     def q(self):
         """Return the total net charge of `Atoms`."""
@@ -420,22 +406,6 @@ class Atoms(MutableSequence):
         self._velocities = velocities[:]
         return np.asarray(self._velocities)
 
-    @property
-    def NN_number(self):
-        return self._NN_number
-
-    @NN_number.setter
-    def NN_number(self, value):
-        self._NN_number = int(value)
-
-    @property
-    def NN_cutoff(self):
-        return self._NN_cutoff
-
-    @NN_cutoff.setter
-    def NN_cutoff(self, value):
-        self._NN_cutoff = value
-
     def add_atomtype(self, atom):
         """Add atom type to :py:attr:`~sknano.chemistry.Atoms.atomtypes` dict.
 
@@ -789,7 +759,6 @@ class Atoms(MutableSequence):
             `Atom` instance object to set target list element to.
 
         """
-        self._check_type(atom)
         self._atoms[index] = atom
         for p, plist in self._property_lists.iteritems():
             plist[index] = getattr(atom, p)
@@ -812,7 +781,6 @@ class Atoms(MutableSequence):
             `Atom` object instance to set target list element to
 
         """
-        self._check_type(atom)
         self._atoms.insert(index, atom)
         for p, plist in self._property_lists.iteritems():
             plist.insert(index, getattr(atom, p))
