@@ -14,6 +14,7 @@ from fractions import gcd
 from collections import OrderedDict
 
 import numpy as np
+np.seterr(all='raise')
 
 try:
     from pint import UnitRegistry
@@ -23,7 +24,8 @@ except ImportError:
     Qty = None
 
 from ..chemistry import Atom
-from ..tools.refdata import CCbond, dVDW
+from ..tools import comparison_symbol_operator_mappings
+from ..tools.refdata import CCbond, dVDW, grams_per_Da
 
 from ._parameter_luts import param_units, param_symbols, param_strfmt
 
@@ -46,8 +48,8 @@ class Nanotube(object):
     bond : float, optional
         Distance between nearest neighbor atoms (i.e., bond length).
         Must be in units of **\u212b**. Default value is
-        the carbon-carbon bond length in graphite:
-        :math:`\\mathrm{a}_{\\mathrm{CC}} = 1.421` \u212b ([SoFaCNTs]_)
+        the carbon-carbon bond length in graphite, approximately
+        :math:`\\mathrm{a}_{\\mathrm{CC}} = 1.42` \u212b
     Lx, Ly, Lz : float, optional
         Spatial extent of nanotube(s) in :math:`x, y, z` dimensions
         in units of **nanometers**. By construction, the nanotube is oriented
@@ -82,11 +84,6 @@ class Nanotube(object):
     verbose : bool, optional
         verbose output
 
-    References
-    ----------
-    .. [SoFaCNTs] Science of Fullerenes and Carbon Nanotubes,
-       M. Dresselhaus, G. Dresselhaus, P. Eklund, 1996, p. 760.
-
     Examples
     --------
 
@@ -102,14 +99,12 @@ class Nanotube(object):
     d: 10
     dR: 30
     N: 20
-    M: 10
     R: (1, 0)
-    bond: 1.421 Å
+    θc: 30.00°
     Ch: 42.63 Å
     T: 2.46 Å
     dt: 13.57 Å
     rt: 6.78 Å
-    θc: 30.00°
 
     Change the chirality to :math:`\\mathbf{C}_{h} = (20, 10)`.
 
@@ -121,14 +116,12 @@ class Nanotube(object):
     d: 10
     dR: 10
     N: 140
-    M: 30
     R: (1, -1)
-    bond: 1.421 Å
+    θc: 19.11°
     Ch: 65.12 Å
     T: 11.28 Å
     dt: 20.73 Å
     rt: 10.36 Å
-    θc: 19.11°
 
     Change the chirality to :math:`\\mathbf{C}_{h} = (20, 0)`.
 
@@ -140,14 +133,12 @@ class Nanotube(object):
     d: 20
     dR: 20
     N: 40
-    M: 20
     R: (1, -1)
-    bond: 1.421 Å
+    θc: 0.00°
     Ch: 49.22 Å
     T: 4.26 Å
     dt: 15.67 Å
     rt: 7.83 Å
-    θc: 0.00°
 
     """
     def __init__(self, n=int, m=int, nx=1, ny=1, nz=1, element1='C',
@@ -169,9 +160,9 @@ class Nanotube(object):
         self._params['d'] = {}
         self._params['dR'] = {}
         self._params['N'] = {}
-        self._params['M'] = {}
+        #self._params['M'] = {}
         self._params['R'] = {}
-        self._params['bond'] = {}
+        #self._params['bond'] = {}
         self._params['chiral_angle'] = {}
         self._params['Ch'] = {}
         self._params['T'] = {}
@@ -216,9 +207,9 @@ class Nanotube(object):
         self._t1 = None
         self._t2 = None
         self._N = None
+        self._chiral_angle = None
         self._Ch = None
         self._T = None
-        self._chiral_angle = None
         self._dt = None
         self._rt = None
         self._M = None
@@ -230,6 +221,10 @@ class Nanotube(object):
         self._Natoms = None
         self._Natoms_per_tube = None
 
+        self._unit_cell_mass = None
+        self._linear_mass_density = None
+        self._tube_mass = None
+
         self._Ntubes = 1
         self._nx = int(nx)
         self._ny = int(ny)
@@ -276,17 +271,27 @@ class Nanotube(object):
         self._t2 = self.compute_t2(n=self._n, m=self._m)
 
         # Compute geometric/physical properties
-        self._chiral_angle = self.compute_chiral_angle(n=self._n, m=self._m)
-        self._Ch = self.compute_Ch(n=self._n, m=self._m, bond=self._bond,
-                                   with_units=self._with_units)
-        self._T = self.compute_T(n=self._n, m=self._m, bond=self._bond,
-                                 with_units=self._with_units)
-        self._dt = self.compute_dt(n=self._n, m=self._m, bond=self._bond,
-                                   with_units=self._with_units)
-        self._rt = self.compute_rt(n=self._n, m=self._m, bond=self._bond,
-                                   with_units=self._with_units)
+        self._chiral_angle = \
+            self.compute_chiral_angle(n=self._n, m=self._m)
 
-        self._M = self.compute_M(n=self._n, m=self._m)
+        self._Ch = \
+            self.compute_Ch(n=self._n, m=self._m, bond=self._bond,
+                            with_units=self._with_units)
+
+        self._T = \
+            self.compute_T(n=self._n, m=self._m, bond=self._bond,
+                           with_units=self._with_units)
+
+        self._dt = \
+            self.compute_dt(n=self._n, m=self._m, bond=self._bond,
+                            with_units=self._with_units)
+
+        self._rt = \
+            self.compute_rt(n=self._n, m=self._m, bond=self._bond,
+                            with_units=self._with_units)
+
+        self._M = \
+            self.compute_M(n=self._n, m=self._m)
 
         self._Lx = \
             self.compute_Lx(n=self._n, m=self._m, nx=self._nx, bond=self._bond,
@@ -299,6 +304,13 @@ class Nanotube(object):
         self._Lz = \
             self.compute_Lz(n=self._n, m=self._m, nz=self._nz, bond=self._bond,
                             with_units=self._with_units)
+
+        self._unit_cell_mass = \
+            self.compute_unit_cell_mass(n=self._n, m=self._m,
+                                        element1=self._element1,
+                                        element2=self._element2,
+                                        with_units=self._with_units)
+
         self._tube_mass = \
             self.compute_tube_mass(n=self._n, m=self._m, nz=self._nz,
                                    element1=self._element1,
@@ -308,14 +320,25 @@ class Nanotube(object):
             self.compute_electronic_type(n=self._n, m=self._m)
 
         # Compute symmetry properties
-        self._R = self.compute_R(n=self._n, m=self._m)
+        self._R = \
+            self.compute_R(n=self._n, m=self._m)
 
         # Compute atomistic properties
-        self._N = self.compute_N(n=self._n, m=self._m)
-        self._Natoms = self.compute_Natoms(n=self._n, m=self._m)
+        self._N = \
+            self.compute_N(n=self._n, m=self._m)
+
+        self._Natoms = \
+            self.compute_Natoms(n=self._n, m=self._m)
+
         self._Natoms_per_tube = \
             self.compute_Natoms_per_tube(n=self._n, m=self._m, nz=self._nz)
 
+        self._linear_mass_density = \
+            self.compute_linear_mass_density(n=self._n, m=self._m,
+                                             element1=self._element1,
+                                             element2=self._element2,
+                                             with_units=self._with_units)
+
         for k, v in self.__dict__.iteritems():
             p = k.strip('_')
             if p in self._params.keys():
@@ -508,7 +531,10 @@ class Nanotube(object):
 
         """
         dR = Nanotube.compute_dR(n=n, m=m)
-        return int(2 * (n**2 + m**2 + n * m) / dR)
+        try:
+            return int(2 * (n**2 + m**2 + n * m) / dR)
+        except ZeroDivisionError:
+            return 0
 
     @property
     def t1(self):
@@ -552,7 +578,10 @@ class Nanotube(object):
 
         """
         dR = Nanotube.compute_dR(n=n, m=m)
-        return int((2 * m + n) / dR)
+        try:
+            return int((2 * m + n) / dR)
+        except ZeroDivisionError:
+            return 0
 
     @property
     def t2(self):
@@ -596,7 +625,10 @@ class Nanotube(object):
 
         """
         dR = Nanotube.compute_dR(n=n, m=m)
-        return -int((2 * n + m) / dR)
+        try:
+            return -int((2 * n + m) / dR)
+        except ZeroDivisionError:
+            return 0
 
     @property
     def Ch(self):
@@ -620,8 +652,10 @@ class Nanotube(object):
             Chiral indices defining the nanotube chiral vector
             :math:`\\mathbf{C}_h = n\\mathbf{a}_1 + m\\mathbf{a}_2 = (n, m)`.
         bond : float, optional
-            Distance between nearest neighbor atoms.
-            Must be in units of **\u212b**.
+            Distance between nearest neighbor atoms (i.e., bond length).
+            Must be in units of **\u212b**. Default value is
+            the carbon-carbon bond length in graphite, approximately
+            :math:`\\mathrm{a}_{\\mathrm{CC}} = 1.42` \u212b
 
         Returns
         -------
@@ -704,6 +738,8 @@ class Nanotube(object):
         .. math::
 
            |\\mathbf{T}| = \\frac{\\sqrt{3} |\\mathbf{C}_{h}|}{d_{R}}
+           = \\frac{\\sqrt{3}a\\sqrt{n^2 + m^2 + nm}}{d_{R}}
+           = \\frac{3a_{\\mathrm{CC}}\\sqrt{n^2 + m^2 + nm}}{d_{R}}
 
         Parameters
         ----------
@@ -711,26 +747,34 @@ class Nanotube(object):
             Chiral indices defining the nanotube chiral vector
             :math:`\\mathbf{C}_h = n\\mathbf{a}_1 + m\\mathbf{a}_2 = (n, m)`.
         bond : float, optional
-            Distance between nearest neighbor atoms.
-            Must be in units of **\u212b**.
-        units : str, optional
-        with_units : bool, optional
+            Distance between nearest neighbor atoms (i.e., bond length).
+            Must be in units of **\u212b**. Default value is
+            the carbon-carbon bond length in graphite, approximately
+            :math:`\\mathrm{a}_{\\mathrm{CC}} = 1.42` \u212b
         length : bool, optional
+            Compute the magnitude (i.e., length) of the translation vector.
         magnitude : bool, optional
+            Return the length of the translation vector **without** units.
+        with_units : bool, optional
+        units : str, optional
 
         Returns
         -------
         float or Qty or 2-tuple of ints
             If `length` is `True` and `with_units` is `False`, then
             return the length of unit cell in \u212b.
+
             If `length` is `True` and `with_units` is `True` and
             magnitude is `True`, then return the length of unit cell
             as a float, but with units in `units`.
+
             If `length` is `True` and `with_units` is `True` and
             magnitude is `False`, then return the length of unit cell
             as a `Quantity` instance and with units in `units`.
+
             If `length` is `False`, return the componets of the
-            translation vector as a 2-tuple of ints (:math:`t_1`, :math:`t_2`).
+            translation vector as a 2-tuple of ints
+            (:math:`t_1`, :math:`t_2`).
 
         """
 
@@ -746,7 +790,10 @@ class Nanotube(object):
                                      magnitude=magnitude)
             dR = Nanotube.compute_dR(n=n, m=m)
 
-            return np.sqrt(3) * Ch / dR
+            try:
+                return np.sqrt(3) * Ch / dR
+            except (FloatingPointError, ZeroDivisionError):
+                return 0
         else:
             t1 = Nanotube.compute_t1(n=n, m=m)
             t2 = Nanotube.compute_t2(n=n, m=m)
@@ -774,8 +821,10 @@ class Nanotube(object):
             Chiral indices defining the nanotube chiral vector
             :math:`\\mathbf{C}_h = n\\mathbf{a}_1 + m\\mathbf{a}_2 = (n, m)`.
         bond : float, optional
-            Distance between nearest neighbor atoms.
-            Must be in units of **\u212b**.
+            Distance between nearest neighbor atoms (i.e., bond length).
+            Must be in units of **\u212b**. Default value is
+            the carbon-carbon bond length in graphite, approximately
+            :math:`\\mathrm{a}_{\\mathrm{CC}} = 1.42` \u212b
 
         Returns
         -------
@@ -809,8 +858,10 @@ class Nanotube(object):
             Chiral indices defining the nanotube chiral vector
             :math:`\\mathbf{C}_h = n\\mathbf{a}_1 + m\\mathbf{a}_2 = (n, m)`.
         bond : float, optional
-            Distance between nearest neighbor atoms.
-            Must be in units of **\u212b**.
+            Distance between nearest neighbor atoms (i.e., bond length).
+            Must be in units of **\u212b**. Default value is
+            the carbon-carbon bond length in graphite, approximately
+            :math:`\\mathrm{a}_{\\mathrm{CC}} = 1.42` \u212b
 
         Returns
         -------
@@ -893,6 +944,11 @@ class Nanotube(object):
         n, m : int
             Chiral indices defining the nanotube chiral vector
             :math:`\\mathbf{C}_h = n\\mathbf{a}_1 + m\\mathbf{a}_2 = (n, m)`.
+        bond : float, optional
+            Distance between nearest neighbor atoms (i.e., bond length).
+            Must be in units of **\u212b**. Default value is
+            the carbon-carbon bond length in graphite, approximately
+            :math:`\\mathrm{a}_{\\mathrm{CC}} = 1.42` \u212b
         length : bool, optional
             If `True`, return :math:`|\\mathbf{R}|`.
         magnitude : bool, optional
@@ -907,13 +963,11 @@ class Nanotube(object):
             is `True` in units of **\u212b**.
 
         """
+        N = Nanotube.compute_N(n=n, m=m)
         t1 = Nanotube.compute_t1(n=n, m=m)
         t2 = Nanotube.compute_t2(n=n, m=m)
-        N = Nanotube.compute_N(n=n, m=m)
-
-        p = None
-        q = None
 
+        p = q = 0
         for i in xrange(0, t1 + n + 1):
             for j in xrange(t2, m + 1):
                 R = t1 * j - t2 * i
@@ -972,8 +1026,7 @@ class Nanotube(object):
             return theta
 
     @classmethod
-    def compute_so(cls, n=int, m=int, bond=None, with_units=False,
-                   units='angstrom', magnitude=True):
+    def compute_so(cls, n=int, m=int, bond=None):
         u"""Compute symmetry operation :math:`(\\psi|\\tau)`.
 
         The *symmetry vector* `R` represents a *symmetry
@@ -992,10 +1045,10 @@ class Nanotube(object):
             Chiral indices defining the nanotube chiral vector
             :math:`\\mathbf{C}_h = n\\mathbf{a}_1 + m\\mathbf{a}_2 = (n, m)`.
         bond : float, optional
-            Distance between nearest neighbor atoms.
-            Must be in units of **\u212b**.
-        rad2deg : bool, optional
-            If `True`, return angle in degrees.
+            Distance between nearest neighbor atoms (i.e., bond length).
+            Must be in units of **\u212b**. Default value is
+            the carbon-carbon bond length in graphite, approximately
+            :math:`\\mathrm{a}_{\\mathrm{CC}} = 1.42` \u212b
 
         Returns
         -------
@@ -1005,8 +1058,7 @@ class Nanotube(object):
 
         """
         psi = Nanotube.compute_psi(n=n, m=m)
-        tau = Nanotube.compute_tau(n=n, m=m, bond=bond, with_units=with_units,
-                                   units=units, magnitude=magnitude)
+        tau = Nanotube.compute_tau(n=n, m=m, bond=bond)
         return (psi, tau)
 
     @classmethod
@@ -1032,7 +1084,10 @@ class Nanotube(object):
 
         """
         N = Nanotube.compute_N(n=n, m=m)
-        return 2 * np.pi / N
+        try:
+            return 2 * np.pi / N
+        except (FloatingPointError, ZeroDivisionError):
+            return 0
 
     @classmethod
     def compute_tau(cls, n=int, m=int, bond=None, with_units=False,
@@ -1050,10 +1105,10 @@ class Nanotube(object):
             Chiral indices defining the nanotube chiral vector
             :math:`\\mathbf{C}_h = n\\mathbf{a}_1 + m\\mathbf{a}_2 = (n, m)`.
         bond : float, optional
-            Distance between nearest neighbor atoms.
-            Must be in units of **\u212b**.
-        rad2deg : bool, optional
-            If `True`, return angle in degrees.
+            Distance between nearest neighbor atoms (i.e., bond length).
+            Must be in units of **\u212b**. Default value is
+            the carbon-carbon bond length in graphite, approximately
+            :math:`\\mathrm{a}_{\\mathrm{CC}} = 1.42` \u212b
 
         Returns
         -------
@@ -1066,7 +1121,10 @@ class Nanotube(object):
         N = Nanotube.compute_N(n=n, m=m)
         T = Nanotube.compute_T(n=n, m=m, bond=bond, with_units=with_units,
                                units=units, length=True, magnitude=magnitude)
-        return M * T / N
+        try:
+            return M * T / N
+        except ZeroDivisionError:
+            return 0
 
     @property
     def nx(self):
@@ -1124,7 +1182,10 @@ class Nanotube(object):
         nx : int
             Number of nanotubes along :math:`x`-axis.
         bond : float, optional
-            Bond length in **\u212b**.
+            Distance between nearest neighbor atoms (i.e., bond length).
+            Must be in units of **\u212b**. Default value is
+            the carbon-carbon bond length in graphite, approximately
+            :math:`\\mathrm{a}_{\\mathrm{CC}} = 1.42` \u212b
 
         Returns
         -------
@@ -1173,7 +1234,10 @@ class Nanotube(object):
         ny : int
             Number of nanotubes along :math:`y`-axis.
         bond : float, optional
-            Bond length in **\u212b**.
+            Distance between nearest neighbor atoms (i.e., bond length).
+            Must be in units of **\u212b**. Default value is
+            the carbon-carbon bond length in graphite, approximately
+            :math:`\\mathrm{a}_{\\mathrm{CC}} = 1.42` \u212b
 
         Returns
         -------
@@ -1229,12 +1293,15 @@ class Nanotube(object):
         nz : {int, float}
             Number of nanotube unit cells
         bond : float, optional
-            bond length in **\u212b**.
+            Distance between nearest neighbor atoms (i.e., bond length).
+            Must be in units of **\u212b**. Default value is
+            the carbon-carbon bond length in graphite, approximately
+            :math:`\\mathrm{a}_{\\mathrm{CC}} = 1.42` \u212b
 
         Returns
         -------
         float
-            :math:`L_{\\mathrm{tube}}` in **nanometers**
+            :math:`L_z = L_{\\mathrm{tube}}` in **nanometers**
 
         """
         T = Nanotube.compute_T(n=n, m=m, bond=bond, with_units=with_units,
@@ -1433,6 +1500,139 @@ class Nanotube(object):
         Natoms = Nanotube.compute_Natoms(n=n, m=m)
         return int(Natoms * nz)
 
+    @property
+    def unit_cell_mass(self):
+        """Unit cell mass in atomic mass units."""
+        return self._unit_cell_mass
+
+    @classmethod
+    def compute_unit_cell_mass(cls, n=int, m=int, element1=None, element2=None,
+                               with_units=False, units='Da', magnitude=True):
+        """Compute nanotube unit cell mass in atomic mass units.
+
+        Parameters
+        ----------
+        n, m : int
+            Chiral indices defining the nanotube chiral vector
+            :math:`\\mathbf{C}_h = n\\mathbf{a}_1 + m\\mathbf{a}_2 = (n, m)`.
+        element1, element2 : {str, int}, optional
+            Element symbol or atomic number of basis
+            :class:`~sknano.chemistry.Atoms` 1 and 2
+        with_units : bool, optional
+            Attach `units` to physical quantities.
+            **This parameter is not yet fully implemented or supported.
+            Use at your own risk!**
+        units : None, optional
+            System of physical units to attach to quantities.
+            **This parameter is not yet fully implemented or supported.
+            Use at your own risk!**
+
+        Returns
+        -------
+        float
+            Unit cell mass in **Daltons**.
+
+        Notes
+        -----
+
+        .. todo::
+
+           Handle different elements and perform accurate calculation by
+           determining number of atoms of each element.
+
+        """
+        N = Nanotube.compute_N(n=n, m=m)
+
+        if element1 is None:
+            element1 = 'C'
+        if element2 is None:
+            element2 = 'C'
+
+        mass = N * (Atom(element1).m + Atom(element2).m)
+        if with_units and Qty is not None:
+            mass = Qty(mass, 'Da')
+            if units is not None and units not in ('Da', 'amu'):
+                mass.ito(units)
+            if magnitude:
+                try:
+                    return mass.magnitude
+                except AttributeError:
+                    return mass
+            else:
+                return mass
+        else:
+            return mass
+
+    @property
+    def linear_mass_density(self):
+        """Linear mass density of nanotube in g/nm."""
+        return self._linear_mass_density
+
+    @classmethod
+    def compute_linear_mass_density(cls, n=int, m=int, bond=None,
+                                    element1=None, element2=None,
+                                    with_units=False, units='grams/nm',
+                                    magnitude=True):
+        """Compute nanotube linear mass density (mass per unit length) in
+        **grams/nm**.
+
+        Parameters
+        ----------
+        n, m : int
+            Chiral indices defining the nanotube chiral vector
+            :math:`\\mathbf{C}_h = n\\mathbf{a}_1 + m\\mathbf{a}_2 = (n, m)`.
+        element1, element2 : {str, int}, optional
+            Element symbol or atomic number of basis
+            :class:`~sknano.chemistry.Atoms` 1 and 2
+        bond : float, optional
+            Distance between nearest neighbor atoms (i.e., bond length).
+            Must be in units of **\u212b**. Default value is
+            the carbon-carbon bond length in graphite, approximately
+            :math:`\\mathrm{a}_{\\mathrm{CC}} = 1.42` \u212b
+        with_units : bool, optional
+            Attach `units` to physical quantities.
+            **This parameter is not yet fully implemented or supported.
+            Use at your own risk!**
+        units : None, optional
+            System of physical units to attach to quantities.
+            **This parameter is not yet fully implemented or supported.
+            Use at your own risk!**
+
+        Returns
+        -------
+        float
+            Linear mass density in units of **g/nm**.
+
+        """
+        mass = Nanotube.compute_unit_cell_mass(n=n, m=m,
+                                               element1=element1,
+                                               element2=element2,
+                                               with_units=False)
+        T = Nanotube.compute_T(n=n, m=m, bond=bond,
+                               with_units=False, length=True)
+
+        try:
+            linear_mass_density = mass / T
+
+            if with_units and Qty is not None:
+                linear_mass_density = Qty(linear_mass_density, 'Da/angstrom')
+                if units is not None:
+                    linear_mass_density.ito(units)
+
+                if magnitude:
+                    try:
+                        return linear_mass_density.magnitude
+                    except AttributeError:
+                        return linear_mass_density
+                else:
+                    return linear_mass_density
+            else:
+                # there are 1.6605e-24 grams / Da and 10 angstroms / nm
+                linear_mass_density *= 10 * grams_per_Da
+                return linear_mass_density
+        except ZeroDivisionError:
+            return 0
+
     @property
     def Ntubes(self):
         """Number of nanotubes."""
@@ -1489,10 +1689,22 @@ class Nanotube(object):
             :math:`\\mathbf{C}_h = n\\mathbf{a}_1 + m\\mathbf{a}_2 = (n, m)`.
         nz : {int, float}
             Number of nanotube unit cells
+        element1, element2 : {str, int}, optional
+            Element symbol or atomic number of basis
+            :class:`~sknano.chemistry.Atoms` 1 and 2
+        with_units : bool, optional
+            Attach `units` to physical quantities.
+            **This parameter is not yet fully implemented or supported.
+            Use at your own risk!**
+        units : None, optional
+            System of physical units to attach to quantities.
+            **This parameter is not yet fully implemented or supported.
+            Use at your own risk!**
 
         Returns
         -------
         float
+            Nanotube mass in **grams**.
 
         Notes
         -----
@@ -1517,16 +1729,54 @@ class Nanotube(object):
         mass = Natoms_per_tube * (atom1.m + atom2.m) / 2
         if with_units and Qty is not None:
             mass = Qty(mass, 'Da')
-            mass.ito(units)
-
-        if magnitude and with_units:
-            try:
-                return mass.magnitude
-            except AttributeError:
+            if units is not None and units not in ('Da', 'amu'):
+                mass.ito(units)
+            if magnitude:
+                try:
+                    return mass.magnitude
+                except AttributeError:
+                    return mass
+            else:
                 return mass
         else:
+            # there are 1.6605e-24 grams / Da
+            mass *= grams_per_Da
             return mass
 
+    @classmethod
+    def filter_Ch_list(cls, Ch_list=None, property_filters=None):
+        """Filter list of chiralities by list of properties.
+
+        Parameters
+        ----------
+        Ch_list : sequence
+            List of chiralities
+        property_filters : sequence
+
+        """
+        if Ch_list is not None and property_filters is not None:
+            filtered_list = Ch_list[:]
+            try:
+                for filter_index, (prop, cmp_symbol, value) in \
+                        enumerate(property_filters, start=1):
+                    cmp_op = comparison_symbol_operator_mappings[cmp_symbol]
+                    tmp_list = []
+                    for Ch in filtered_list:
+                        n, m = Ch
+                        nanotube = Nanotube(n=n, m=m)
+                        try:
+                            if cmp_op(getattr(nanotube, prop), value):
+                                tmp_list.append(Ch)
+                        except AttributeError:
+                            break
+                    filtered_list = tmp_list[:]
+            except ValueError as e:
+                print(e)
+            finally:
+                return filtered_list
+        else:
+            return None
+
 
 class NanotubeBundle(Nanotube):
     u"""Class for creating interactive Nanotube bundle objects.
@@ -1544,8 +1794,8 @@ class NanotubeBundle(Nanotube):
     bond : float, optional
         Bond length between nearest neighbor atoms.
         Must be in units of **\u212b**. Default value is
-        the carbon-carbon bond length in graphite:
-        :math:`\\mathrm{a}_{\\mathrm{CC}} = 1.421` \u212b ([SoFaCNTs]_)
+        the carbon-carbon bond length in graphite, approximately
+        :math:`\\mathrm{a}_{\\mathrm{CC}} = 1.42` \u212b
     Lx, Ly, Lz : float, optional
         Length of bundle in :math:`x, y, z` dimensions in **nanometers**.
         Overrides the :math:`n_x, n_y, n_z` cell values.
@@ -1782,7 +2032,9 @@ class NanotubeBundle(Nanotube):
 
         if with_units and Qty is not None:
             bundle_density = Qty(bundle_density, 'Da/angstroms**3')
-            bundle_density.ito(units)
+            if units is not None:
+                bundle_density.ito(units)
+
             if magnitude:
                 try:
                     return bundle_density.magnitude
@@ -1792,7 +2044,7 @@ class NanotubeBundle(Nanotube):
                 return bundle_density
         else:
             # there are 1.6605e-24 grams / Da and 1e-8 cm / angstrom
-            bundle_density *= 1.6605e-24 / (1e-8)**3
+            bundle_density *= grams_per_Da / (1e-8)**3
             return bundle_density
 
     @property
@@ -1828,8 +2080,7 @@ class NanotubeBundle(Nanotube):
             Nanotube bundle mass :math:`M_{\\mathrm{bundle}}` in **grams**.
 
         """
-        Ntubes = \
-            NanotubeBundle.compute_Ntubes(nx=nx, ny=ny)
+        Ntubes = NanotubeBundle.compute_Ntubes(nx=nx, ny=ny)
         tube_mass = Nanotube.compute_tube_mass(n=n, m=m, nz=nz,
                                                element1=element1,
                                                element2=element2,
