@@ -7,7 +7,7 @@ Unit cell vectors (:mod:`sknano.nanogen._vectors`)
 .. currentmodule:: sknano.nanogen._vectors
 
 """
-from __future__ import division, print_function, absolute_import
-__docformat__ = 'restructuredtext'
+from __future__ import absolute_import, division, print_function
+__docformat__ = 'restructuredtext en'
 
 __all__ = []
