@@ -71,6 +71,7 @@ Examples
 
 """
 from __future__ import absolute_import, division, print_function
+__docformat__ = 'restructuredtext en'
 
 import argparse
 import sys
@@ -84,7 +85,7 @@ from ..tools.refdata import CCbond
 __all__ = ['nanogen']
 
 
-def _argparser():
+def argparser():
     parser = argparse.ArgumentParser()
     parser.add_argument('--format', default='xyz', dest='fmt',
                         choices=tuple([fmt for fmt in format_ext.iterkeys()]),
@@ -223,7 +224,7 @@ def nanogen(fmt='xyz', units='angstrom', element1='C', element2='C',
 
 def main():
 
-    args = _argparser().parse_args()
+    args = argparser().parse_args()
     nanogen(**vars(args))
 
 if __name__ == '__main__':
