@@ -15,8 +15,7 @@ import os
 
 import numpy as np
 
-#from ..chemistry import Atom
-from .atoms import LAMMPSAtom as Atom
+from .atoms import LAMMPSAtom as Atom, LAMMPSAtoms, lammps_atom_styles
 from ..tools import get_fpath
 
 from ._structure_data import StructureReader, StructureWriter, \
@@ -24,72 +23,7 @@ from ._structure_data import StructureReader, StructureWriter, \
     default_comment_line
 
 __all__ = ['DATAData', 'DATAReader', 'DATAWriter', 'DATA2XYZConverter',
-           'DATAFormat', 'DATAError', 'LAMMPSDATA', 'atom_style_map']
-
-
-atom_style_map = {}
-atom_style_map['angle'] = \
-    ['atom-ID', 'molecule-ID', 'atom-type', 'x', 'y', 'z', 'nx', 'ny', 'nz']
-
-atom_style_map['atomic'] = \
-    ['atom-ID', 'atom-type', 'x', 'y', 'z', 'nx', 'ny', 'nz']
-
-atom_style_map['body'] = \
-    ['atom-ID', 'atom-type', 'bodyflag', 'mass',
-     'x', 'y', 'z', 'nx', 'ny', 'nz']
-
-atom_style_map['bond'] = \
-    ['atom-ID', 'molecule-ID', 'atom-type', 'x', 'y', 'z', 'nx', 'ny', 'nz']
-
-atom_style_map['charge'] = \
-    ['atom-ID', 'atom-type', 'q', 'x', 'y', 'z', 'nx', 'ny', 'nz']
-
-atom_style_map['dipole'] = \
-    ['atom-ID', 'atom-type', 'q', 'x', 'y', 'z',
-     'mux', 'muy', 'muz', 'nx', 'ny', 'nz']
-
-atom_style_map['electron'] = \
-    ['atom-ID', 'atom-type', 'q', 'spin', 'eradius',
-     'x', 'y', 'z', 'nx', 'ny', 'nz']
-
-atom_style_map['ellipsoid'] = \
-    ['atom-ID', 'atom-type', 'ellipsoidflag', 'density',
-     'x', 'y', 'z', 'nx', 'ny', 'nz']
-
-atom_style_map['full'] = \
-    ['atom-ID', 'molecule-ID', 'atom-type', 'q',
-     'x', 'y', 'z', 'nx', 'ny', 'nz']
-
-atom_style_map['line'] = \
-    ['atom-ID', 'molecule-ID', 'atom-type', 'lineflag', 'density',
-     'x', 'y', 'z', 'nx', 'ny', 'nz']
-
-atom_style_map['meso'] = \
-    ['atom-ID', 'atom-type', 'rho', 'e', 'cv',
-     'x', 'y', 'z', 'nx', 'ny', 'nz']
-
-atom_style_map['molecular'] = \
-    ['atom-ID', 'molecule-ID', 'atom-type', 'x', 'y', 'z', 'nx', 'ny', 'nz']
-
-atom_style_map['peri'] = \
-    ['atom-ID', 'atom-type', 'volume', 'density',
-     'x', 'y', 'z', 'nx', 'ny', 'nz']
-
-atom_style_map['sphere'] = \
-    ['atom-ID', 'atom-type', 'diameter', 'density',
-     'x', 'y', 'z', 'nx', 'ny', 'nz']
-
-atom_style_map['template'] = \
-    ['atom-ID', 'molecule-ID', 'template-index', 'template-atom',
-     'atom-type', 'x', 'y', 'z', 'nx', 'ny', 'nz']
-
-atom_style_map['tri'] = \
-    ['atom-ID', 'molecule-ID', 'atom-type', 'triangleflag', 'density',
-     'x', 'y', 'z', 'nx', 'ny', 'nz']
-
-atom_style_map['wavepacket'] = \
-    ['atom-ID', 'atom-type', 'charge', 'spin', 'eradius', 'etag',
-     'cs_re', 'cs_im', 'x', 'y', 'z', 'nx', 'ny', 'nz']
+           'DATAFormat', 'DATAError', 'LAMMPSDATA']
 
 
 class DATAReader(StructureReader):
@@ -105,7 +39,7 @@ class DATAReader(StructureReader):
     def __init__(self, fpath=None, atom_style='full'):
         super(DATAReader, self).__init__(fpath=fpath)
 
-        #self._structure_atoms = LAMMPSAtoms()
+        self._structure_atoms = LAMMPSAtoms()
 
         data_format = DATAFormat(atom_style=atom_style)
         self._data_headers = data_format.properties['headers']
@@ -167,6 +101,12 @@ class DATAReader(StructureReader):
                         found = True
                         f.readline()
                         Nitems = self._headers[header_key]
+                        #self._sections[section_key] = \
+                        #    [[props['dtype'](s) for props in
+                        #        self._section_properties[
+                        #            section_key].itervalues() for
+                        #        s in f.readline().strip().split()] for n in
+                        #        xrange(Nitems)]
                         data = []
                         for n in xrange(Nitems):
                             tmp = []
@@ -180,12 +120,6 @@ class DATAReader(StructureReader):
                                     break
                             data.append(tmp)
                         self._sections[section_key] = data[:]
-                        #self._sections[section_key] = \
-                        #    [[props['dtype'](s) for props in
-                        #        self._section_properties[
-                        #            section_key].itervalues() for
-                        #        s in f.readline().strip().split()] for n in
-                        #        xrange(Nitems)]
                         break
                 f.readline()
                 line = f.readline().strip()
@@ -319,9 +253,9 @@ class DATAWriter(StructureWriter):
 
     @classmethod
     def write(cls, fname=None, outpath=None, fpath=None, atoms=None,
-              boxbounds=None, comment_line=None, assume_unique_atoms=False,
-              enforce_consecutive_atomIDs=True, pad_box=True, xpad=10.,
-              ypad=10., zpad=10., verbose=False):
+              atom_style='full', boxbounds=None, comment_line=None,
+              assume_unique_atoms=False, enforce_consecutive_atomIDs=True,
+              pad_box=True, xpad=10., ypad=10., zpad=10., verbose=False):
         """Write structure data to file.
 
         Parameters
@@ -406,6 +340,7 @@ class DATAWriter(StructureWriter):
 
         with open(fpath, 'w') as f:
             f.write('# {}\n\n'.format(comment_line.lstrip('#').strip()))
+
             f.write('{}atoms\n'.format(
                 '{:d}'.format(Natoms).ljust(Natoms_width)))
             f.write('{}atom types\n\n'.format(
@@ -494,13 +429,14 @@ class DATA2XYZConverter(StructureConverter):
         `XYZReader` (only if `return_reader` is True)
 
         """
+        from .atoms import AtomsConverter
         from ._xyz_format import XYZReader, XYZWriter
 
         datareader = DATAReader(fpath=self.infile)
-        atoms = datareader.atoms
+        atoms = AtomsConverter(atoms=datareader.atoms, to='xyz').atoms
         comment_line = datareader.comment_line
 
-        XYZWriter.write(fname=self.outfile, atoms=atoms,
+        XYZWriter.write(fpath=self.outfile, atoms=atoms,
                         comment_line=comment_line)
 
         if return_reader:
@@ -519,13 +455,12 @@ class DATAData(DATAReader):
         super(DATAData, self).__init__(fpath=fpath)
 
     def delete(self, key):
-        pass
-
-    def findtime(self, n):
-        pass
-
-    def iterator(self, n):
-        pass
+        if key in self.headers:
+            del self._headers[key]
+        elif key in self.sections:
+            del self._sections[key]
+        else:
+            raise DATAError('{} not in DATA object'.format(key))
 
     def map(self, *pairs):
         pass
@@ -653,75 +588,14 @@ class DATAFormat(StructureFormat):
     """
     def __init__(self, atom_style='full'):
         super(DATAFormat, self).__init__()
+        self._atom_style = atom_style
         self._section_properties = OrderedDict()
 
         atoms_section_syntax = {}
-        atoms_section_syntax['angle'] = \
-            ['atomID', 'moleculeID', 'atomtype',
-             'x', 'y', 'z', 'nx', 'ny', 'nz']
-
-        atoms_section_syntax['atomic'] = \
-            ['atomID', 'atomtype', 'x', 'y', 'z', 'nx', 'ny', 'nz']
-
-        atoms_section_syntax['body'] = \
-            ['atomID', 'atomtype', 'bodyflag', 'mass',
-             'x', 'y', 'z', 'nx', 'ny', 'nz']
-
-        atoms_section_syntax['bond'] = \
-            ['atomID', 'moleculeID', 'atomtype',
-             'x', 'y', 'z', 'nx', 'ny', 'nz']
-
-        atoms_section_syntax['charge'] = \
-            ['atomID', 'atomtype', 'q',
-             'x', 'y', 'z', 'nx', 'ny', 'nz']
-
-        atoms_section_syntax['dipole'] = \
-            ['atomID', 'atomtype', 'q', 'x', 'y', 'z',
-             'mux', 'muy', 'muz', 'nx', 'ny', 'nz']
-
-        atoms_section_syntax['electron'] = \
-            ['atomID', 'atomtype', 'q', 'spin', 'eradius', 'x', 'y', 'z',
-             'nx', 'ny', 'nz']
-
-        atoms_section_syntax['ellipsoid'] = \
-            ['atomID', 'atomtype', 'ellipsoidflag', 'density',
-             'x', 'y', 'z', 'nx', 'ny', 'nz']
-
-        atoms_section_syntax['full'] = \
-            ['atomID', 'moleculeID', 'atomtype', 'q',
-             'x', 'y', 'z', 'nx', 'ny', 'nz']
-
-        atoms_section_syntax['line'] = \
-            ['atomID', 'moleculeID', 'atomtype', 'lineflag', 'density',
-             'x', 'y', 'z', 'nx', 'ny', 'nz']
-
-        atoms_section_syntax['meso'] = \
-            ['atomID', 'atomtype', 'rho', 'e', 'cv',
-             'x', 'y', 'z', 'nx', 'ny', 'nz']
-
-        atoms_section_syntax['molecular'] = \
-            ['atomID', 'moleculeID', 'atomtype',
-             'x', 'y', 'z', 'nx', 'ny', 'nz']
-
-        atoms_section_syntax['peri'] = \
-            ['atomID', 'atomtype', 'volume', 'density',
-             'x', 'y', 'z', 'nx', 'ny', 'nz']
-
-        atoms_section_syntax['sphere'] = \
-            ['atomID', 'atomtype', 'diameter', 'density',
-             'x', 'y', 'z', 'nx', 'ny', 'nz']
-
-        atoms_section_syntax['template'] = \
-            ['atomID', 'moleculeID', 'template-index', 'template-atom',
-             'atomtype', 'x', 'y', 'z', 'nx', 'ny', 'nz']
-
-        atoms_section_syntax['tri'] = \
-            ['atomID', 'moleculeID', 'atomtype', 'triangleflag', 'density',
-             'x', 'y', 'z', 'nx', 'ny', 'nz']
-
-        atoms_section_syntax['wavepacket'] = \
-            ['atomID', 'atomtype', 'charge', 'spin', 'eradius', 'etag',
-             'cs_re', 'cs_im', 'x', 'y', 'z', 'nx', 'ny', 'nz']
+        for atom_style, var_list in lammps_atom_styles.iteritems():
+            atoms_section_syntax[atom_style] = []
+            for var in var_list:
+                atoms_section_syntax[atom_style].append(var.replace('-', ''))
 
         velocities_section_syntax = {}
         velocities_section_syntax['full'] = ['atomID', 'vx', 'vy', 'vz']
@@ -734,9 +608,9 @@ class DATAFormat(StructureFormat):
 
         section_keys = ['Atoms', 'Masses', 'Velocities']
         self._section_syntax_dict = \
-            {'Atoms': atoms_section_syntax[atom_style],
+            {'Atoms': atoms_section_syntax[self.atom_style],
              'Masses': ['atomtype', 'mass'],
-             'Velocities': velocities_section_syntax[atom_style]}
+             'Velocities': velocities_section_syntax[self.atom_style]}
 
         for section_key in section_keys:
             self._section_properties[section_key] = OrderedDict()
@@ -747,39 +621,47 @@ class DATAFormat(StructureFormat):
                      'colnum': i+1,
                      'index': i}
 
-        self._header_keys = ["atoms",
-                             "atom types",
-                             "bonds",
-                             "bond types",
-                             "angles",
-                             "angle types",
-                             "dihedrals",
-                             "dihedral types",
-                             "impropers",
-                             "improper types",
-                             "bodies",
-                             "ellipsoids",
-                             "lines",
-                             "triangles",
-                             "xlo xhi",
-                             "ylo yhi",
-                             "zlo zhi",
-                             "xy xz yz"]
+        self._header_keys = ['atoms',
+                             'bonds',
+                             'angles',
+                             'dihedrals',
+                             'impropers',
+                             'atom types',
+                             'bond types',
+                             'angle types',
+                             'dihedral types',
+                             'improper types',
+                             'extra bond per atom',
+                             'extra angle per atom',
+                             'extra dihedral per atom',
+                             'extra improper per atom',
+                             'ellipsoids',
+                             'lines',
+                             'triangles',
+                             'bodies',
+                             'xlo xhi',
+                             'ylo yhi',
+                             'zlo zhi',
+                             'xy xz yz']
 
         self._headers = {'atoms': {'dtype': int, 'items': 1},
-                         'atom types': {'dtype': int, 'items': 1},
                          'bonds': {'dtype': int, 'items': 1},
-                         'bond types': {'dtype': int, 'items': 1},
                          'angles': {'dtype': int, 'items': 1},
-                         'angle types': {'dtype': int, 'items': 1},
                          'dihedrals': {'dtype': int, 'items': 1},
-                         'dihedral types': {'dtype': int, 'items': 1},
                          'impropers': {'dtype': int, 'items': 1},
+                         'atom types': {'dtype': int, 'items': 1},
+                         'bond types': {'dtype': int, 'items': 1},
+                         'angle types': {'dtype': int, 'items': 1},
+                         'dihedral types': {'dtype': int, 'items': 1},
                          'improper types': {'dtype': int, 'items': 1},
-                         'bodies': {'dtype': int, 'items': 1},
+                         'extra bond per atom': {'dtype': int, 'items': 1},
+                         'extra angle per atom': {'dtype': int, 'items': 1},
+                         'extra dihedral per atom': {'dtype': int, 'items': 1},
+                         'extra improper per atom': {'dtype': int, 'items': 1},
                          'ellipsoids': {'dtype': int, 'items': 1},
                          'lines': {'dtype': int, 'items': 1},
                          'triangles': {'dtype': int, 'items': 1},
+                         'bodies': {'dtype': int, 'items': 1},
                          'xlo xhi': {'dtype': float, 'items': 2},
                          'ylo yhi': {'dtype': float, 'items': 2},
                          'zlo zhi': {'dtype': float, 'items': 2},
@@ -787,6 +669,11 @@ class DATAFormat(StructureFormat):
 
         self._properties['headers'] = self._headers
 
+        # A LAMMPS data file is partitioned into sections identified
+        # by a keyword string. The header data are used by one or
+        # more sections. The `section_header_map` maps each
+        # section keyword to a specific header key.
+
         self._section_header_map = {}
 
         atoms_sections = ['Atoms', 'Velocities', 'Molecules']
@@ -852,6 +739,11 @@ class DATAFormat(StructureFormat):
 
         self._properties['sections'] = self._section_header_map
 
+    @property
+    def atom_style(self):
+        """Atom style."""
+        return self._atom_style
+
     @property
     def header_keys(self):
         """List of header key names"""
