@@ -12,7 +12,7 @@ __docformat__ = 'restructuredtext en'
 
 import os
 
-from ..chemistry import Atom, Atoms
+from ..chemistry import Atom
 from ..tools import get_fpath
 
 from ._structure_data import StructureReader, StructureReaderError, \
@@ -59,14 +59,18 @@ class ZMATRIXWriter(StructureWriter):
     """Class for writing zmatrix chemical file format."""
 
     @classmethod
-    def write(cls, fname=None, outpath=None, atoms=None, comment_line=None):
+    def write(cls, fname=None, outpath=None, fpath=None, atoms=None,
+              comment_line=None):
         """Write structure data to file.
 
         Parameters
         ----------
-        fname : str
+        fname : str, optional
+            Output file name.
         outpath : str, optional
-            Output path for structure data file.
+            Output file path.
+        fpath : str, optional
+            Full path (directory path + file name) to output data file.
         atoms : :py:class:`~sknano.chemistry.Atoms`
             An :py:class:`~sknano.chemistry.Atoms` instance.
         comment_line : str, optional
@@ -74,22 +78,20 @@ class ZMATRIXWriter(StructureWriter):
             then it is set to the full path of the output `zmatrix` file.
 
         """
-        if not isinstance(atoms, Atoms):
-            raise TypeError('atoms argument must be an `Atoms` instance')
-        else:
+        if fpath is None:
             fpath = get_fpath(fname=fname, ext='zmatrix', outpath=outpath,
                               overwrite=True, add_fnum=False)
-            if comment_line is None:
-                comment_line = default_comment_line
+        if comment_line is None:
+            comment_line = default_comment_line
 
-            atoms.rezero_coords()
+        atoms.rezero_coords()
 
-            with open(fpath, 'w') as f:
-                f.write('{:d}\n'.format(atoms.Natoms))
-                f.write('{}\n'.format(comment_line))
-                for atom in atoms:
-                    f.write('{:>3s}{:15.8f}{:15.8f}{:15.8f}\n'.format(
-                        atom.symbol, atom.x, atom.y, atom.z))
+        with open(fpath, 'w') as f:
+            f.write('{:d}\n'.format(atoms.Natoms))
+            f.write('{}\n'.format(comment_line))
+            for atom in atoms:
+                f.write('{:>3s}{:15.8f}{:15.8f}{:15.8f}\n'.format(
+                    atom.symbol, atom.x, atom.y, atom.z))
 
 
 class ZMATRIXDATA(ZMATRIXReader):
