@@ -21,16 +21,22 @@ Contents
 
    Atom
    Atoms
+   AtomsConverter
    LAMMPSAtom
    LAMMPSAtoms
+   XYZAtom
+   XYZAtoms
 
 """
-from __future__ import division, print_function, absolute_import
+from __future__ import absolute_import, division, print_function
 __docformat__ = 'restructuredtext en'
 
 from ._atom import *
 from ._atoms import *
+from ._atoms_converter import *
 from ._lammps_atom import *
 from ._lammps_atoms import *
+from ._xyz_atom import *
+from ._xyz_atoms import *
 
 __all__ = [s for s in dir() if not s.startswith('_')]
