@@ -7,9 +7,9 @@ Reference data (:mod:`sknano.tools.refdata._constants`)
 .. currentmodule:: sknano.tools.refdata._constants
 
 """
-from __future__ import division, print_function, absolute_import
+from __future__ import absolute_import, division, print_function
 
-C_C = CCbond = 1.421  # angstroms
+C_C = CCbond = 1.42  # angstroms
 C_H = CHbond = 1.09  # angstroms
 dVDW = 3.4  # angstroms
 
